@@ -52,6 +52,21 @@ class RPMTransactionItemWrapper(object):
     def match(self, pattern):
         return True
 
+    def is_package(self):
+        return self._item.getRPMItem() is not None
+
+    def is_group(self):
+        return self._item.getCompsGroupItem() is not None
+
+    def is_environment(self):
+        return self._item.getCompsEnvironmentItem() is not None
+
+    def get_group(self):
+        return self._item.getCompsGroupItem()
+
+    def get_environment(self):
+        return self._item.getCompsEnvironmentItem()
+
     @property
     def name(self):
         return self._item.getRPMItem().getName()
@@ -78,6 +93,10 @@ class RPMTransactionItemWrapper(object):
             return "{}:{}-{}".format(self.epoch, self.version, self.release)
         return "{}-{}".format(self.version, self.release)
 
+    @property
+    def nevra(self):
+        return self._item.getRPMItem().getNEVRA()
+
     @property
     def action(self):
         return self._item.getAction()
@@ -362,6 +381,9 @@ class SwdbInterface(object):
                 prev_trans.altered_gt_rpmdb = True
         return result[::-1]
 
+    def get_current(self):
+        return TransactionWrapper(self.swdb.getCurrent())
+
     def set_reason(self, pkg, reason):
         """Set reason for package"""
         rpm_item = self.rpm._pkg_to_swdb_rpm_item(pkg)
